@@ -29,6 +29,9 @@ MainWindow::MainWindow (QWidget *parent)
 , mtxDial (QMutex::Recursive)
 , bCallInProgress (false)
 , bDialCancelled (false)
+, logMutex (QMutex::Recursive)
+, logsTimer (this)
+, bKickLocksTimer (false)
 #if MOSQUITTO_CAPABLE
 , mqThread (QString("qgvdial:%1").arg(QHostInfo::localHostName())
             .toLatin1().constData (), this)
@@ -85,6 +88,11 @@ MainWindow::initLogging ()
     strLogfile += "qgvdial.log";
     fLogfile.setFileName (strLogfile);
     fLogfile.open (QIODevice::WriteOnly | QIODevice::Append);
+
+    logsTimer.setSingleShot (true);
+    logsTimer.start (3 * 1000);
+    QObject::connect (&logsTimer, SIGNAL(timeout()),
+                       this     , SLOT(onCleanupLogsArray()));
 }//MainWindow::initLogging
 
 /** Log information to console and to log file
@@ -118,8 +126,34 @@ MainWindow::log (const QString &strText, int level /*= 10*/)
         QTextStream streamLog(&fLogfile);
         streamLog << strLog << endl;
     }
+
+    // Append it to the circular buffer
+    QMutexLocker locker(&logMutex);
+    arrLogMsgs.prepend (strLog);
+    bKickLocksTimer = true;
 }//MainWindow::log
 
+void
+MainWindow::onCleanupLogsArray()
+{
+    do { // Begin cleanup block (not a loop)
+        QMutexLocker locker(&logMutex);
+        if (!bKickLocksTimer) {
+            break;
+        }
+        bKickLocksTimer = false;
+
+        while (arrLogMsgs.size () > 50) {
+            arrLogMsgs.removeLast ();
+        }
+
+        QDeclarativeContext *ctx = this->rootContext();
+        ctx->setContextProperty ("g_logModel", QVariant::fromValue(arrLogMsgs));
+    } while (0); // End cleanup block (not a loop)
+
+    logsTimer.start (3 * 1000);
+}//MainWindow::onCleanupLogsArray
+
 /** Status update function
  * Use this function to update the status. The status is shown dependent on the
  * platform. On Windows and Linux, this status is shown on the system tray as a
@@ -402,6 +436,7 @@ MainWindow::initQML ()
     ctx->setContextProperty ("g_strMsgText", "No message");
     ctx->setContextProperty ("g_CurrentPhoneName", "Not loaded");
     ctx->setContextProperty ("g_vmailPlayerState", iTempZero);
+    ctx->setContextProperty ("g_logModel", QVariant::fromValue(arrLogMsgs));
 
     // Initialize the QML view
     this->setSource (QUrl ("qrc:/Main.qml"));
