@@ -10,6 +10,10 @@ class SkypeClientFactory;
 class ObserverFactory;
 class CallInitiatorFactory;
 
+// For some reason the symbian MOC doesn't like it if I don't include QObject
+// even though it is present in QtCore which is included in global.h
+#include <QObject>
+
 class Singletons : public QObject
 {
 public:
